/// <reference types="node" />
import { EventEmitter } from 'events';
import { IConnectionConfig } from '../port/connection/connection.config.interface';
import { IOcariotRabbitMQClient } from '../port/ocariot.rabbitmq.client.interface';
import { IConnectionOption } from '../port/connection/connection.option.interface';
export declare class OcariotRabbitMQClient extends EventEmitter implements IOcariotRabbitMQClient {
    private appName;
    private readonly _connConfig;
    private readonly _connOpt;
    private defaultOptionRpcClient;
    private defaultConnConfig;
    private _pubConnection?;
    private _pubConnectionInitialized?;
    private _subConnection?;
    private _subConnectionInitialized?;
    private _serverConnection?;
    private _serverConnectionInitialized?;
    private _clientConnection?;
    private _clientConnectionInitialized?;
    constructor(appName: string, connParams?: IConnectionConfig | string, connOptions?: IConnectionOption);
    private pubEventInitialization;
    private subEventInitialization;
    private serverEventInitialization;
    private clientEventInitialization;
    logger(level: string, moduleName?: string): void;
    close(): Promise<void>;
    private pubConnection;
    private publish;
    pub(routingKey: string, body: any): Promise<void>;
    private subConnection;
    sub(routingKey: string, callback: (message: any) => void): Promise<void>;
    private subscribe;
    private serverConnection;
    private resource;
    provide(name: string, func: (...any: any[]) => any): Promise<void>;
    getResource(name: string, params: any[], callback: (err: Error, result: any) => any): void;
    getResource(name: string, params: any[]): Promise<any>;
    private requestResource;
    getResourceCallback(exchangeName: string, name: string, params: any[], callback: (...any: any[]) => any): void;
    getResourcePromise(exchangeName: string, name: string, params: any[]): Promise<any>;
    pubSavePhysicalActivity(activity: any): Promise<void>;
    pubUpdatePhysicalActivity(activity: any): Promise<void>;
    pubDeletePhysicalActivity(activity: any): Promise<void>;
    pubSaveSleep(sleep: any): Promise<void>;
    pubUpdateSleep(sleep: any): Promise<void>;
    pubDeleteSleep(sleep: any): Promise<void>;
    pubSaveWeight(weight: any): Promise<void>;
    pubDeleteWeight(weight: any): Promise<void>;
    pubSaveEnvironment(environment: any): Promise<void>;
    pubDeleteEnvironment(environment: any): Promise<void>;
    pubSaveLog(log: any): Promise<void>;
    pubSaveChild(child: any): Promise<void>;
    pubUpdateChild(child: any): Promise<void>;
    pubUpdateFamily(family: any): Promise<void>;
    pubUpdateEducator(educator: any): Promise<void>;
    pubUpdateHealthProfessional(healthprofessional: any): Promise<void>;
    pubUpdateApplication(application: any): Promise<void>;
    pubDeleteUser(user: any): Promise<void>;
    pubDeleteInstitution(institution: any): Promise<void>;
    pubFitbitLastSync(fitbit: any): Promise<void>;
    pubFitbitAuthError(fitbit: any): Promise<void>;
    pubFitbitRevoke(fitbit: any): Promise<void>;
    pubSyncPhysicalActivity(activity: any): Promise<void>;
    pubSyncSleep(sleep: any): Promise<void>;
    pubSyncWeight(weight: any): Promise<void>;
    pubSyncLog(log: any): Promise<void>;
    pubSaveFood(food: any): Promise<void>;
    pubUpdateFood(food: any): Promise<void>;
    subSavePhysicalActivity(callback: (message: any) => void): Promise<void>;
    subUpdatePhysicalActivity(callback: (message: any) => void): Promise<void>;
    subDeletePhysicalActivity(callback: (message: any) => void): Promise<void>;
    subSaveSleep(callback: (message: any) => void): Promise<void>;
    subUpdateSleep(callback: (message: any) => void): Promise<void>;
    subDeleteSleep(callback: (message: any) => void): Promise<void>;
    subSaveWeight(callback: (message: any) => void): Promise<void>;
    subDeleteWeight(callback: (message: any) => void): Promise<void>;
    subSaveEnvironment(callback: (message: any) => void): Promise<void>;
    subDeleteEnvironment(callback: (message: any) => void): Promise<void>;
    subSaveLog(callback: (message: any) => void): Promise<void>;
    subSaveChild(callback: (message: any) => void): Promise<void>;
    subUpdateChild(callback: (message: any) => void): Promise<void>;
    subUpdateFamily(callback: (message: any) => void): Promise<void>;
    subUpdateEducator(callback: (message: any) => void): Promise<void>;
    subUpdateHealthProfessional(callback: (message: any) => void): Promise<void>;
    subUpdateApplication(callback: (message: any) => void): Promise<void>;
    subDeleteUser(callback: (message: any) => void): Promise<void>;
    subDeleteInstitution(callback: (message: any) => void): Promise<void>;
    subFitbitLastSync(callback: (message: any) => void): Promise<void>;
    subFitbitAuthError(callback: (message: any) => void): Promise<void>;
    subFitbitRevoke(callback: (message: any) => void): Promise<void>;
    subSyncPhysicalActivity(callback: (message: any) => void): Promise<void>;
    subSyncSleep(callback: (message: any) => void): Promise<void>;
    subSyncWeight(callback: (message: any) => void): Promise<void>;
    subSyncLog(callback: (message: any) => void): Promise<void>;
    subSaveFood(callback: (message: any) => void): Promise<void>;
    subUpdateFood(callback: (message: any) => void): Promise<void>;
    providePhysicalActivities(listener: (query?: string) => any): Promise<void>;
    provideSleep(listener: (query?: string) => any): Promise<void>;
    provideWeights(listener: (query?: string) => any): Promise<void>;
    provideEnvironments(listener: (query?: string) => any): Promise<void>;
    provideLogs(listener: (childId: string, dateStart: string, dateEnd: string) => any): Promise<void>;
    provideChildren(listener: (query?: string) => any): Promise<void>;
    provideFamilies(listener: (query?: string) => any): Promise<void>;
    provideFamilyChildren(listener: (family_id: string) => any): Promise<void>;
    provideEducators(listener: (query?: string) => any): Promise<void>;
    provideEducatorChildrenGroups(listener: (educator_id: string) => any): Promise<void>;
    provideHealthProfessionals(listener: (query?: string) => any): Promise<void>;
    provideHealthProfessionalChildrenGroups(listener: (healthprofessional_id: string) => any): Promise<void>;
    provideApplications(listener: (query?: string) => any): Promise<void>;
    provideInstitutions(listener: (query?: string) => any): Promise<void>;
    provideEducatorsFromChild(listener: (childId: string) => any): Promise<void>;
    provideHealthProfessionalsFromChild(listener: (childId: string) => any): Promise<void>;
    provideFoods(listener: (childId: string, dateStart: string, dateEnd: string) => any): Promise<void>;
    getPhysicalActivities(query: string, callback: (err: Error, result: any) => void): void;
    getPhysicalActivities(query?: string): Promise<any>;
    getSleep(query: string, callback: (err: Error, result: any) => void): void;
    getSleep(query?: string): Promise<any>;
    getWeights(query: string, callback: (err: Error, result: any) => void): void;
    getWeights(query?: string): Promise<any>;
    getEnvironments(query: string, callback: (err: Error, result: any) => void): void;
    getEnvironments(query?: string): Promise<any>;
    getLogs(childId: string, dateStart: string, dateEnd: string, callback: (err: Error, result: any) => void): void;
    getLogs(childId: string, dateStart: string, dateEnd: string): Promise<any>;
    getChildren(query: string, callback: (err: Error, result: any) => void): void;
    getChildren(query?: string): Promise<any>;
    getFamilies(query: string, callback: (err: Error, result: any) => void): void;
    getFamilies(query?: string): Promise<any>;
    getFamilyChildren(familyId: string, callback: (err: Error, result: any) => void): void;
    getFamilyChildren(familyId: string): Promise<any>;
    getEducators(query: string, callback: (err: Error, result: any) => void): void;
    getEducators(query?: string): Promise<any>;
    getEducatorChildrenGroups(educatorId: string, callback: (err: Error, result: any) => void): void;
    getEducatorChildrenGroups(educatorId: string): Promise<any>;
    getHealthProfessionals(query: string, callback: (err: Error, result: any) => void): void;
    getHealthProfessionals(query?: string): Promise<any>;
    getHealthProfessionalChildrenGroups(healthProfessionalId: string, callback: (err: Error, result: any) => void): void;
    getHealthProfessionalChildrenGroups(healthProfessionalId: string): Promise<any>;
    getApplications(query: string, callback: (err: Error, result: any) => void): void;
    getApplications(query?: string): Promise<any>;
    getInstitutions(query: string, callback: (err: Error, result: any) => void): void;
    getInstitutions(query?: string): Promise<any>;
    getEducatorsFromChild(childId: string, callback: (err: Error, result: any) => void): void;
    getEducatorsFromChild(childId: string): Promise<any>;
    getHealthProfessionalsFromChild(childId: string, callback: (err: Error, result: any) => void): void;
    getHealthProfessionalsFromChild(childId: string): Promise<any>;
    getFoods(childId: string, dateStart: string, dateEnd: string, callback: (err: Error, result: any) => void): void;
    getFoods(childId: string, dateStart: string, dateEnd: string): Promise<any>;
}
